#!/bin/bash

PRELEASE="indt3"
PNAME="expedite"
PVER="$(pkg-config --modversion evas)_${PRELEASE}"
SECTION="user/accessories"

DEF_PKGS="expedite"

DESC="Expedite - Evas Benchmark suite"
LONG_DESC="\
 Homepage: http://www.enlightenment.org/
"
BDEPENDS="pkg-config, efl-core"
DEPENDS="efl-core (>= 0.9.9.040_indt3)"

ARCH="$(arch)"

export CFLAGS="$CFLAGS -DNDEBUG=1 -fomit-frame-pointer -O2 -mfpu=vfp -mfloat-abi=softfp -mcpu=arm1136jf-s -ffast-math -funsafe-math-optimizations -fno-math-errno -fsingle-precision-constant"
DESTDIR="/tmp/$PNAME-$ARCH"

PKGS="$@"
if [ x"$PKGS" = x ]; then
	PKGS=$DEF_PKGS
fi

die() {
	echo "ERROR: $@"
	exit 1
}

if [ x"$NODESTDIR" != x1 ]; then
    rm -fr $DESTDIR
fi

LOG_PREFIX="$(basename $0)"

CWD=$PWD
for p in $PKGS; do
    PKG_OPTS_NAME="OPTS_$p"
    PKG_OPTS="${!PKG_OPTS_NAME}"
    LOG="/tmp/${LOG_PREFIX}__$p.log"

    echo "Build: $p"
    echo "$(date) ---- $p" >> "$LOG"
    cd $CWD/$p || die "missing package $p"

    if [ x"$NORECONFIGURE" != x1 ]; then
        if [ -f Makefile ] && [  x"$NOMAKE" != x1 ]; then
            (make uninstall && make distclean) >/dev/null 2>> "$LOG"
        fi
        NOCONFIGURE=1 ./autogen.sh >/dev/null 2>> "$LOG" || die "failed to autogen.sh $p"

        OPTS="--prefix=/usr"
        ./configure $OPTS $PKG_OPTS >/dev/null 2>> "$LOG" || die "failed to configure $p"
    fi

    if [ x"$NOMAKE" != x1 ]; then
        make >/dev/null 2>> "$LOG" || die "failed to make $p"
        make install >/dev/null 2>> "$LOG" || die "failed to install $p"
    fi

    if [ x"$NODESTDIR" != x1 ]; then
        make DESTDIR=$DESTDIR install >/dev/null 2>> "$LOG"
    fi
    cd $CWD
done

if [ x"$NODESTDIR" != x1 ]; then
    cd $DESTDIR
    tar czf $DESTDIR.tar.gz .
    cd $CWD
fi

##
## Clean
##
find $DESTDIR/usr/lib -name '*.a' -exec rm \{\} \;
find $DESTDIR/usr/lib -name '*.la' -exec rm \{\} \;
find $DESTDIR/usr/lib -name '*.so' -exec strip -s \{\} \;
rm -fr $DESTDIR/usr/include
rm -fr $DESTDIR/usr/bin/*-config
rm -fr $DESTDIR/usr/lib/pkgconfig
SIZE=$(du -sc $DESTDIR | grep total | sed s/total//)

MENU_DIR="$DESTDIR/usr/share/applications/hildon"
mkdir -p "$MENU_DIR"

cat > "$MENU_DIR/expedite-x11.desktop" <<EOF
[Desktop Entry]
Encoding=UTF-8
Version=1.0
Type=Application
Name=Expedite - X11
Exec=/usr/bin/expedite -e x11
EOF

cat > "$MENU_DIR/expedite-x11-16.desktop" <<EOF
[Desktop Entry]
Encoding=UTF-8
Version=1.0
Type=Application
Name=Expedite - X11-16
Exec=/usr/bin/expedite -e x11-16
EOF


##
## Package
##
PDIR="${DESTDIR}-deb"
mkdir -p $PDIR
cd $PDIR
cat > control <<EOF
Package: $PNAME
Version: $PVER
Section: $SECTION
Priority: optional
Architecture: armel
Installed-Size: $SIZE
Maintainer: Gustavo Sverzut Barbieri <gustavo.barbieri@openbossa.org>
Build-Depends: $BDEPENDS
Depends: $DEPENDS
Description: $DESC
$LONG_DESC
EOF
echo 2.0 > debian-binary
tar czf control.tar.gz control
(cd $DESTDIR; tar czf $PDIR/data.tar.gz .)
rm -f ${PNAME}_${PVER}.deb
ar q ${PNAME}_${PVER}_armel.deb debian-binary control.tar.gz data.tar.gz
echo $PWD/${PNAME}_${PVER}_armel.deb
